function fourier(ac, x, y)      %model 1 and 2 predictions, called by historical.m and averaged.m

    today = datetime('09-05-2018','inputformat','MM-dd-yyyy'); %for marking the present day in graphs
    
    pastx = NaT(1,ac);         %divides the input data into past and future segments so they can be displayed
                               %individually in graphs
    for i=1:ac
        pastx(i) = x(i);
    end
    
    pasty = zeros(1,ac);
 
    for i=1:ac
        pasty(i) = y(i);
    end
    
    futurex = NaT(1,length(x)-ac+1);
 
    for i=1:length(x)-ac+1
        futurex(i) = x(i+ac-1);
    end
    
    futurey = zeros(1,length(y)-ac+1);
 
    for i=1:length(y)-ac+1
        futurey(i) = y(i+ac-1);
    end
    
    fakex = zeros(1,ac);              %converts the input of dates into real numbers so that they can be
                                      %inputted into calculations 
    for i=1:ac
        fakex(i)= datenum(x(i)) - datenum(x(1)) + 1;
    end

    
    p=polyfit(fakex,pasty,1);         %creates a least-squares trendline of the past data
    
    lst= zeros(1,ac);
    
    for i=1:ac
        lst(i)=p(1)*fakex(i)+p(2);
    end

    
    hold on;                         %displays a graph of the relevant past data, along with a trendline
    plot(pastx,pasty,'Color',[.6 0 0]);
    plot(pastx,lst,'b');
    xtickformat('MMM-dd');
    axis tight;
    title('Stock Data');
    xlabel('Days');
    ylabel('Closing Price');
    legend({'Closing Price','Trendline'},'Location','northwest');

    
    figure
    
    dtd = zeros(1,ac);

    for i = 1:ac                    %Subtraction of the data and the trendline to center data along x axis
        dtd(i) = pasty(i)-lst(i);
    end
    
    if ac < 40                                  %Fourier Series fit based on size of autocorrelation
        fterm= 'Fourier Series with 2 Terms';
        f=fit(fakex',dtd','fourier2');
    end
    
    if ac >= 40 && ac < 60
        fterm= 'Fourier Series with 3 Terms';
        f=fit(fakex',dtd','fourier3');
    end
    
    if ac >= 60
        fterm= 'Fourier Series with 4 Terms';
        f=fit(fakex',dtd','fourier4');
    end
    
    for i=1:ac+17                                     %Fourier Series fit extended into future
        fakex(i)= datenum(x(i)) - datenum(x(1)) + 1;
    end
    
    for i=1:ac+17
        lst(i)=p(1)*fakex(i)+p(2);
    end

    
    model = zeros(1,ac);
    
    for i = 1:ac
        model(i) = f(fakex(i));
    end
    
    hold on;                                %displays a graph of the centered data and Fourier Series fit
    plot(pastx,dtd,'Color',[.6 0 0]);
    plot(pastx,model,'Color',[0 0.6 0]);
    axis tight;
    xtickformat('MMM-dd');
    title(fterm)
    xlabel('Days');
    ylabel('Closing Price');
    legend({'Data-Trendline Difference','Fourier Series'},'Location','northwest');
    
    figure
    
    yh= zeros(1,ac+17);          %uses trendline and Fourier Series fit to create prediction of future
    
    for i=1:ac+17                   
        yh(i)=lst(i)+f(fakex(i));
    end
    
    noise = zeros(1,ac);
    
    for i = 1:ac                 %creates margin of error based on how different past data and prediction are
        noise(i) = yh(i) - pasty(i);
    end
    
    maximum = abs(max(noise));
    
    minimum = abs(min(noise));
    
    error = (maximum+minimum)/2;   %calculates size of error
    
    disp(error*2*100);             %prints out the size of error
     
    yhf = zeros(1,length(yh)-ac+1);
    
    for i=1:length(yh)-ac+1           %extracts prediction into only its future segment
        yhf(i) = yh(i+ac-1);
    end
    
    upperband = zeros(1,length(yh)-ac+1);
    
    lowerband = zeros(1,length(yh)-ac+1);
    
    for i = 1:ac+17                   %create error bands based on size of error       
        upperband(i) = yh(i) + error;
        lowerband(i) = yh(i) - error;
    end
    
    
    
    fupperband = zeros(1,length(yh)-ac+1);     %extends error bands into the future
    
    flowerband = zeros(1,length(yh)-ac+1);
    
    for i = 1:length(yh)-ac+1
        fupperband(i) = upperband(i+ac-1);
        flowerband(i) = lowerband(i+ac-1);
    end
    
    
    hold on;                             %creates a graph displaying the relevant data, the prediction of  
    plot(x,y,'Color',[.6 0 0]);          %the data, and the error bands
    plot(x,yh,'Color',[0 .6 0]);
    plot(x,upperband,'Color',[0 0 .6],'Linestyle','--');
    plot(x,lowerband,'Color',[0 0 .6],'Linestyle','--');
    line([today today], [min(lowerband) max(upperband)],'Color','k','LineStyle','--');
    axis tight;
    xtickformat('MMM-dd');
    title('Price Prediction');   
    xlabel('Days');
    ylabel('Closing Price');
    legend({'Closing Price','Price Prediction','Error Bound','Sep 05'},'Location','northwest');

    
    figure;
   
    
    hold on;                                 %creates a graph displaying the same information as the previous
    plot(futurex,futurey,'Color',[.6 0 0]);  %but only portraying the future segment of it
    plot(futurex,yhf,'Color',[0 .6 0]);
    plot(futurex,fupperband,'Color',[0 0 .6],'Linestyle','--');
    plot(futurex,flowerband,'Color',[0 0 .6],'Linestyle','--');
    axis tight;
    xtickformat('MMM-dd');
    title('Price Prediction');   
    xlabel('Days');
    ylabel('Closing Price');
    legend({'Closing Price','Price Prediction','Error Bound'},'Location','northwest');
    
    
end